# Http Server Agent Blueprint

This is the "HTTP Echo" agent blueprint!

## Description

The agent blueprint uses its http connection to listen to http requests.

It then routes requests to its skill and echos them.

The agent blueprint is also a demonstration of applying environment variables via config over-rides and defaults.

* <a href="https://stack.olas.network/open-aea/http-connection-and-skill/" target="_blank">Http Connection and Skill</a>
